﻿/*
 * Console Calendar by Matthew Malensek
 * 
 * Just a simple text-based calendar.
 * Feel free to modify, copy, distribute,
 * or use in any way you see fit.
 * 
 */

using System;
using System.Text;
using System.Text.RegularExpressions;

namespace calendar
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length > 0)
            {
                Console.WriteLine("Console Calendar by Matthew Malensek");
                Console.WriteLine("------------------------------------");
                Console.WriteLine();
                Console.WriteLine("Controls:");
                Console.WriteLine("  <-   Back one month");
                Console.WriteLine("  ->   Forward one month");
                Console.WriteLine("  G    Toggle graphics mode");
                Console.WriteLine("  Q    Exit");

                return;
            }

            //store initial location of the cursor
            int cursorX = Console.CursorLeft;
            int cursorY = Console.CursorTop;
            Console.CursorVisible = false;

            ConsoleKey key = new ConsoleKey();

            Calendar cal = new Calendar();

            do
            {
                if (key == ConsoleKey.RightArrow)
                {
                    cal++;
                }
                else if (key == ConsoleKey.LeftArrow)
                {
                    cal--;
                }
                else if (key == ConsoleKey.G)
                {
                    Properties.Settings.Default.graphics = !Properties.Settings.Default.graphics;
                    Properties.Settings.Default.Save();
                    Console.CursorLeft = cursorX;
                    Console.CursorTop = cursorY;
                }

                String calendarStr = cal.ToString();

                //if graphics are turned off, remove them from the calendar string
                if (!Properties.Settings.Default.graphics)
                {
                    //remove non-alphanumeric chars, keeping whitespace and newlines
                    Regex r = new Regex(@"[^\w\n()]");
                    calendarStr = r.Replace(calendarStr, " ");
                }
                Console.WriteLine(calendarStr);
                Console.CursorLeft = cursorX;
                Console.CursorTop = cursorY;

            } while ((key = Console.ReadKey().Key) != ConsoleKey.Q);

            Console.CursorTop = Console.CursorTop + 22;
        }
    }
}












































/*
Console.WriteLine();
Console.WriteLine("      ▄▄▄▄            ▄▄▄▄       ");
Console.WriteLine(" ┌────────────────────────────┐  ");
Console.WriteLine(" │           July 08          │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │  S   M   T   W   T   F   S │▐ ");
Console.WriteLine(" ├────────────────────────────┤▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │          1   2   3   4   5 │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │  6   7   8   9  10  11  12 │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │ 13  14  15  16  17  18  19 │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │ 20  21  22  23 (24) 25  26 │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │ 27  28  29  30  31         │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" │                            │▐ ");
Console.WriteLine(" └────────────────────────────┘▐ ");
Console.WriteLine("   ▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀ ");
Console.ReadKey();
 * */